"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const Constants_1 = require("./Constants");
const zosmf_for_zowe_sdk_1 = require("@zowe/zosmf-for-zowe-sdk");
const zos_tso_for_zowe_sdk_1 = require("@zowe/zos-tso-for-zowe-sdk");
const zos_uss_for_zowe_sdk_1 = require("@zowe/zos-uss-for-zowe-sdk");
const core_for_zowe_sdk_1 = require("@zowe/core-for-zowe-sdk");
const config = {
    productDisplayName: Constants_1.Constants.DISPLAY_NAME,
    commandModuleGlobs: [
        "daemon/*.definition!(.d).*s",
        "provisioning/*.definition!(.d).*s",
        "workflows/*.definition!(.d).*s",
        "zosconsole/*.definition!(.d).*s",
        "zosfiles/*.definition!(.d).*s",
        "zosjobs/*.definition!(.d).*s",
        "zosmf/*.definition!(.d).*s",
        "zostso/*.definition!(.d).*s",
        "zosuss/*.definition!(.d).*s",
        "zoslogs/*.definition!(.d).*s"
    ],
    rootCommandDescription: Constants_1.Constants.DESCRIPTION,
    defaultHome: Constants_1.Constants.HOME_DIR,
    envVariablePrefix: Constants_1.Constants.ENV_PREFIX,
    webHelpLogoImgPath: path.join(__dirname, "..", "web-help-logo.png"),
    logging: {
        appLogging: {
            logFile: Constants_1.Constants.LOG_LOCATION
        }
    },
    apimlConnLookup: [
        {
            apiId: "ibm.zosmf",
            gatewayUrl: "api/v1",
            connProfType: "zosmf"
        }
    ],
    baseProfile: Object.assign(Object.assign({}, core_for_zowe_sdk_1.ProfileConstants.BaseProfile), { authConfig: [
            {
                serviceName: "apiml",
                handler: __dirname + "/auth/ApimlAuthHandler",
                login: {
                    summary: core_for_zowe_sdk_1.ProfileConstants.APIML_LOGIN_SUMMARY,
                    description: core_for_zowe_sdk_1.ProfileConstants.APIML_LOGIN_DESCRIPTION,
                    examples: [
                        core_for_zowe_sdk_1.ProfileConstants.APIML_LOGIN_EXAMPLE1,
                        core_for_zowe_sdk_1.ProfileConstants.APIML_LOGIN_EXAMPLE2
                    ],
                    options: [
                        core_for_zowe_sdk_1.ProfileConstants.BASE_OPTION_HOST,
                        core_for_zowe_sdk_1.ProfileConstants.BASE_OPTION_PORT,
                        core_for_zowe_sdk_1.ProfileConstants.BASE_OPTION_USER,
                        core_for_zowe_sdk_1.ProfileConstants.BASE_OPTION_PASSWORD,
                        core_for_zowe_sdk_1.ProfileConstants.BASE_OPTION_REJECT_UNAUTHORIZED,
                        core_for_zowe_sdk_1.ProfileConstants.BASE_OPTION_CERT_FILE,
                        core_for_zowe_sdk_1.ProfileConstants.BASE_OPTION_CERT_KEY_FILE
                    ]
                },
                logout: {
                    summary: core_for_zowe_sdk_1.ProfileConstants.APIML_LOGOUT_SUMMARY,
                    description: core_for_zowe_sdk_1.ProfileConstants.APIML_LOGOUT_DESCRIPTION,
                    examples: [
                        core_for_zowe_sdk_1.ProfileConstants.APIML_LOGOUT_EXAMPLE1,
                        core_for_zowe_sdk_1.ProfileConstants.APIML_LOGOUT_EXAMPLE2
                    ],
                    options: [
                        core_for_zowe_sdk_1.ProfileConstants.BASE_OPTION_HOST,
                        core_for_zowe_sdk_1.ProfileConstants.BASE_OPTION_PORT,
                        core_for_zowe_sdk_1.ProfileConstants.APIML_LOGOUT_OPTION_TOKEN_TYPE,
                        core_for_zowe_sdk_1.ProfileConstants.BASE_OPTION_TOKEN_VALUE,
                        core_for_zowe_sdk_1.ProfileConstants.BASE_OPTION_REJECT_UNAUTHORIZED
                    ]
                }
            }
        ] }),
    authGroupConfig: {
        authGroup: {
            summary: core_for_zowe_sdk_1.ProfileConstants.AUTH_GROUP_SUMMARY,
            description: core_for_zowe_sdk_1.ProfileConstants.AUTH_GROUP_DESCRIPTION
        }
    },
    configAutoInitCommandConfig: {
        handler: __dirname + "/config/auto-init/ApimlAutoInitHandler",
        provider: "APIML",
        autoInit: {
            options: [
                core_for_zowe_sdk_1.ProfileConstants.AUTO_INIT_OPTION_HOST,
                core_for_zowe_sdk_1.ProfileConstants.AUTO_INIT_OPTION_PORT,
                core_for_zowe_sdk_1.ProfileConstants.AUTO_INIT_OPTION_USER,
                core_for_zowe_sdk_1.ProfileConstants.AUTO_INIT_OPTION_PASSWORD,
                core_for_zowe_sdk_1.ProfileConstants.AUTO_INIT_OPTION_REJECT_UNAUTHORIZED,
                core_for_zowe_sdk_1.ProfileConstants.AUTO_INIT_OPTION_TOKEN_TYPE,
                core_for_zowe_sdk_1.ProfileConstants.AUTO_INIT_OPTION_TOKEN_VALUE,
                core_for_zowe_sdk_1.ProfileConstants.AUTO_INIT_OPTION_CERT_FILE,
                core_for_zowe_sdk_1.ProfileConstants.AUTO_INIT_OPTION_CERT_KEY_FILE
            ]
        },
        profileType: "base"
    },
    profiles: [
        zosmf_for_zowe_sdk_1.ZosmfProfile,
        zos_tso_for_zowe_sdk_1.ZosTsoProfile,
        zos_uss_for_zowe_sdk_1.ZosUssProfile
    ]
};
module.exports = config;
//# sourceMappingURL=imperative.js.map